==> haskell-pipes-http-1.0.6-318-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-LYPD3Bm1ghJEqlIgJejdkS
key:                  pipes-http-1.0.6-LYPD3Bm1ghJEqlIgJejdkS
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  395ed5ac93431b78ca958860490a5600
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-8.10.4/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/pipes-http-1.0.6
hs-libraries:         HSpipes-http-1.0.6-LYPD3Bm1ghJEqlIgJejdkS
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    http-client-0.7.6-Fl64LorVH623IKAfFBdTA6
    http-client-tls-0.3.5.3-3OmivDlKHe9KP0iZ3HnZEh
    pipes-4.3.15-BzZri1pSILpIc025sjEraC

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.6-319-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-8gujwZxfogpKgBGjBRCs17
key:                  pipes-http-1.0.6-8gujwZxfogpKgBGjBRCs17
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  0ba983a1864498004a70428020e7ea87
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-8.10.4/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/pipes-http-1.0.6
hs-libraries:         HSpipes-http-1.0.6-8gujwZxfogpKgBGjBRCs17
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    http-client-0.7.6-G9lB0SI44qcITuwr9igRR3
    http-client-tls-0.3.5.3-49EYFNJPO5K72zSd6dLQMG
    pipes-4.3.15-mwHMT4WMvIAjbupFZ6kLW

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
